@@ -42,6 +42,7 @@
 
 
 
+#include <config.h>
 #include "emboss.h"
 
 
@@ -236,8 +237,10 @@ int main(int argc, char **argv)
 
 	    ajListPushAppend(listin,tmphitlist);
 	    embDmxHitlistToScophits(listin, listout);
-	    ajListSortTwoThree(listout,ajDmxScophitCompAcc, ajDmxScophitCompStart, 
-			ajDmxScophitCompEnd);
+	    ajListSortTwoThree(listout,
+			       &ajDmxScophitCompAcc,
+			       &ajDmxScophitCompStart, 
+			       &ajDmxScophitCompEnd);
           
 	    /* Eleminate identical hits. */
 	    iter=ajListIterNewread(listout); 
@@ -267,8 +270,9 @@ int main(int argc, char **argv)
      
 	    /* The end of the list been reached. 
 	       Delete hits in the list that are targetted for removal. */
-	    ajListPurge(listout, (const void *) ajDmxScophitCheckTarget,
-			ajDmxScophitDelWrap);
+	    ajListPurge(listout,
+			(int (*)(const void *)) &ajDmxScophitCheckTarget,
+			&ajDmxScophitDelWrap);
           
 	    /* Recreate the hitlist for printing. */
 	    embDmxScophitsToHitlist(listout,&hitlist,&iter);
@@ -474,7 +478,7 @@ static AjPFile seqsearch_psialigned(AjPStr seqname,
 
     /* Write psiblast multiple sequence input file. */
     if((*scopalg))
-	nseqs = (*scopalg)->N;
+	nseqs = (*scopalg)->Number;
     else
 	nseqs = ajSeqsetGetSize(seqset);
 
@@ -703,7 +707,6 @@ static EmbPHitlist seqsearch_ReadPsiblastOutput(AjPScopalg scopalg,
     ajint   fragend    = 0;     /* End of sequence fragment. */
     ajint   hitn       = 0;     /* The number of the hit we are on. */
     ajint   nhits      = 0;     /* No. of hits in alignment file. */
-    ajint   fseekr     = 0;
 
     float   offset     = 0;
     float   eval       = 0;
@@ -723,7 +726,8 @@ static EmbPHitlist seqsearch_ReadPsiblastOutput(AjPScopalg scopalg,
     while(ajReadlineTrim(psif,&line))
         if(ajStrFindCaseC(line,"score = ")>=0)
             nhits++;
-    fseekr = ajFileSeek(psif,offset,SEEK_SET);
+
+    ajFileSeek(psif,offset,SEEK_SET);
     
     
     /* Allocate memory for Hitlist object. */
